﻿using System;
using System.Net;
using System.Reflection;
using System.Threading;
using System.Windows.Forms;

namespace MonoUsaKuma.GetNSIP {

    /// <summary>
    /// アプリケーション
    /// </summary>
    public class App {

        //********************************************************************************
        #region フィールド
        //********************************************************************************

        /// <summary>
        /// WebアクセスのURL
        /// </summary>
        private const string WA_URL = "http://www.buffalonas.com/{0}";

        /// <summary>
        /// 正常終了時にウィンドウを閉じるまでの時間
        /// </summary>
        private const int WAIT_MS = 2000;

        #endregion

        //********************************************************************************
        #region メソッド
        //********************************************************************************

        /// <summary>
        /// ここから始まる
        /// </summary>
        /// <param name="args"></param>
        /// <returns></returns>
        [STAThread]
        public static int Main(string[] args) {

            // タイトルを表示する
            Assembly asm = Assembly.GetExecutingAssembly();
            Console.WriteLine(Application.ProductName + " バージョン " + Application.ProductVersion + "\n"
                + ((AssemblyCopyrightAttribute)Attribute.GetCustomAttribute(asm, typeof(AssemblyCopyrightAttribute))).Copyright.Replace("©", "(c)")
                + "\n");

            try {

                // パラメータが無ければ使い方を表示して終了する
                if (args.Length == 0) throw new Exception(
                    ((AssemblyDescriptionAttribute)Attribute.GetCustomAttribute(asm, typeof(AssemblyDescriptionAttribute))).Description
                    + "\n\n[使い方] " + asm.GetName().Name + " <NAS名>");

                // サーバーにアクセスしてＩＰアドレスを取得する
                string url = string.Format(WA_URL, args[0]);
                HttpWebRequest req = (HttpWebRequest)WebRequest.Create(url);
                HttpWebResponse res = null;

                try {

                    Console.WriteLine(url);
                    Console.WriteLine("接続しています...\n");
                    res = (HttpWebResponse)req.GetResponse();
                    // 認証せずに戻ってきた場合は名前が間違っているかも
                    throw new Exception("指定した名前は登録されていない可能性があります。");

                } catch (WebException e) {
                
                    // 認証エラーが出た場合は設定されているアドレスを取得する
                    if (e.Status == WebExceptionStatus.TrustFailure) {
                        // ip:port として取得されたとしてIPアドレスを切り出す
                        string ip = req.Host.Split(':')[0];
                        // クリップボードにコピーする
                        Console.WriteLine("IPアドレス(" + ip + ")をクリップボードにコピーしました。");
                        Clipboard.SetText(ip);
                        // 時間をおいてウィンドウを閉じる
                        Thread.Sleep(WAIT_MS);
                    } else { throw; }

                } catch {
                    throw;
                } finally {
                    if (res != null) res.Close();
                }

                // 正常終了
                return 0;

            } catch (Exception e) {
                // エラーが出たら表示して異常終了
                Console.WriteLine(e.Message);
                Console.WriteLine("\n何かキーを押して下さい...");
                Console.ReadKey(true);
                return -1;
            }

        }

        #endregion

    } // class

} // namespace
